let currentIntervalMinutes = 5; // משתנה ששומר את תדירות הבדיקה בדקות
let wiggleAnimationInterval = null; // משתנה ששומר את האינטרוול של אנימציית הכשכוש

// פונקציה שיוצרת מסמך offscreen לשימוש בניגון צלילים ברקע
async function createOffscreenDocument() {
  const offscreenUrl = chrome.runtime.getURL('offscreen.html');
  if (!(await chrome.offscreen.hasDocument())) {
    await chrome.offscreen.createDocument({
      url: offscreenUrl,
      reasons: ['AUDIO_PLAYBACK'],
      justification: 'Play notification sound for new notifications'
    });
  }
}

// פונקציה שמפעילה אנימציית כשכוש עם צבעי Badge
async function startWiggleAnimation(unreadCount) {
  if (wiggleAnimationInterval) return; // אם האנימציה כבר פועלת, אל תתחיל מחדש

  const colors = ['#FF0000', '#00FF00', '#FF0000']; // אדום, ירוק, חזרה לאדום
  let index = 0;

  wiggleAnimationInterval = setInterval(() => {
    chrome.action.setBadgeBackgroundColor({ color: colors[index % colors.length] });
    index++;
  }, 200); // החלף צבע כל 200 מ"ש

  // עצור את האנימציה אחרי 3 שניות (15 מחזורים)
  setTimeout(() => {
    clearInterval(wiggleAnimationInterval);
    wiggleAnimationInterval = null;
    // חזור לצבע אדום קבוע
    chrome.action.setBadgeBackgroundColor({ color: '#FF0000' });
    updateBadge(unreadCount); // עדכן את ה-Badge עם המספר הנכון
  }, 3000);
}

// פונקציה שמעדכנת את תדירות הבדיקה של ההתראות
function updateCheckInterval(minutes) {
  currentIntervalMinutes = minutes;
  chrome.alarms.clear('checkNotifications', () => {
    chrome.alarms.create('checkNotifications', {
      periodInMinutes: minutes,
      delayInMinutes: minutes
    });
  });
}

// הקשבה להודעות מהפופאפ או מאפשרויות
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (request.action === "fetchNotifications") {
    fetch(request.url, { credentials: 'include' })
      .then(response => response.json())
      .then(data => sendResponse({ data: data }))
      .catch(error => sendResponse({ error: error.toString() }));
    return true;
  } else if (request.action === "updateCheckInterval") {
    updateCheckInterval(request.interval);
  } else if (request.action === "markNotificationRead") {
    updateNotificationState(request.siteName, request.notificationId);
    sendResponse({ success: true });
    return true;
  } else if (request.action === "playSound") {
    sendResponse({ success: true });
    return true;
  } else if (request.action === "syncBadge") {
    updateNotificationState(request.siteName, null, request.unreadCount);
    sendResponse({ success: true });
    return true;
  } else if (request.action === "updateBadge") {
    updateBadge(request.totalUnread);
    sendResponse({ success: true });
    return true;
  }
});

// פונקציה שבודקת אם יש להציג התראה
async function shouldShowNotification(hasChanges) {
  if (!hasChanges) return false; // אם אין שינויים, אל תציג התראה

  const muteState = await chrome.storage.local.get('muteUntil');
  if (muteState.muteUntil && new Date(muteState.muteUntil) > new Date()) {
    return false; // אם התוסף מושתק, אל תציג התראה
  }
  return true;
}

// פונקציה שבודקת אם יש שינויים בהתראות
function areNotificationsChanged(oldState, newState) {
  if (!oldState) return newState.totalCount > 0; // אם אין מצב ישן, בדוק אם יש התראות חדשות

  if (oldState.totalCount !== newState.totalCount) return true;

  const allSites = new Set([
    ...Object.keys(oldState.siteNotifications || {}),
    ...Object.keys(newState.siteNotifications || {})
  ]);

  for (const site of allSites) {
    const oldCount = oldState.siteNotifications[site] || 0;
    const newCount = newState.siteNotifications[site] || 0;
    if (oldCount !== newCount) return true;
  }
  return false;
}

// פונקציה שמעדכנת את מצב ההתראות
async function updateNotificationState(siteName, notificationId, newCount = null) {
  const currentState = await chrome.storage.local.get('notificationsState');
  const state = currentState.notificationsState || { totalCount: 0, siteNotifications: {} };

  if (notificationId && state.siteNotifications[siteName] && state.siteNotifications[siteName] > 0) {
    state.totalCount--;
    state.siteNotifications[siteName]--;
    if (state.siteNotifications[siteName] === 0) {
      delete state.siteNotifications[siteName];
    }
  } else if (newCount !== null) {
    state.totalCount = state.totalCount - (state.siteNotifications[siteName] || 0) + newCount;
    state.siteNotifications[siteName] = newCount;
  }

  chrome.storage.local.set({ notificationsState: state });
  updateBadge(state.totalCount);
}

// פונקציה שבודקת התראות ברקע
async function checkNotificationsBackground() {
  let totalUnreadCount = 0;
  let siteNotifications = {};

  const sites = await new Promise(resolve => {
    chrome.storage.sync.get('sites', data => {
      resolve(data.sites || [
        { url: 'https://tchumim.com', name: 'תחומים', enabled: true },
        { url: 'https://mitmachim.top', name: 'מתמחים', enabled: true },
        { url: 'https://f2.freeivr.co.il', name: 'פורום ימות המשיח', enabled: true },
        { url: 'https://forum-office.co.il', name: 'פורום אופיס', enabled: true },
        { url: 'https://forum.netfree.link', name: 'פורום נטפרי', enabled: true },
        { url: 'https://forum.safera.co.il', name: 'פורום סייפר', enabled: true },
        { url: 'https://rechavimzelaze.ovh', name: 'רכבים זה לזה', enabled: true },
        { url: 'https://miktzav.com', name: 'מקצב', enabled: true },
        { url: 'https://hamusicay.com', name: 'המוזיקאי', enabled: true }
      ]);
    });
  });

  const enabledSites = sites.filter(site => site.enabled); // מסנן את האתרים המופעלים

  for (const site of enabledSites) {
    try {
      const response = await fetch(`${site.url}/api/notifications`, { credentials: 'include' });
      const data = await response.json();

      if (!data.status || data.status.code !== "not-authorised") {
        const unreadCount = data.notifications.filter(n => !n.read).length;
        totalUnreadCount += unreadCount;
        siteNotifications[site.name] = unreadCount;
      }
    } catch (error) {
      siteNotifications[site.name] = 0; // אם יש שגיאה, סמן 0 התראות
    }
  }

  const oldState = await chrome.storage.local.get('notificationsState').then(data => data.notificationsState);
  const newState = {
    totalCount: totalUnreadCount,
    siteNotifications: siteNotifications,
    lastChecked: new Date().toISOString()
  };

  const hasChanges = areNotificationsChanged(oldState, newState);
  const shouldNotify = await shouldShowNotification(hasChanges);

  if (totalUnreadCount > 0) {
    updateBadge(totalUnreadCount);
    if (shouldNotify) {
      chrome.notifications.create('newNotifications', {
        type: 'basic',
        iconUrl: 'icons/icon48.png',
        title: 'התראות חדשות',
        message: `יש לך ${totalUnreadCount} התראות חדשות`,
        priority: 1,
        requireInteraction: false
      });
      const soundSettings = await chrome.storage.sync.get('playSound');
      if (soundSettings.playSound !== false) {
        await createOffscreenDocument();
        chrome.runtime.sendMessage({ action: 'playSound' });
      }
      if (hasChanges) {
        startWiggleAnimation(totalUnreadCount);
      }
    }
  } else {
    updateBadge(0);
  }

  chrome.storage.local.set({ notificationsState: newState });
}

// פונקציה שמעדכנת את ה-Badge עם מספר ההתראות
function updateBadge(count) {
  if (count > 0) {
    chrome.action.setBadgeText({ text: count.toString() });
    chrome.action.setBadgeBackgroundColor({ color: '#FF0000' });
  } else {
    chrome.action.setBadgeText({ text: '' });
  }
}

// פונקציה שמפעילה את בדיקת ההתראות ברקע
function startBackgroundCheck() {
  chrome.storage.sync.get('checkIntervalMinutes', (data) => {
    const interval = data.checkIntervalMinutes || 5;
    currentIntervalMinutes = interval;
    checkNotificationsBackground();
    updateCheckInterval(interval);
  });
}

// הקשבה לאירועי Alarm
chrome.alarms.onAlarm.addListener((alarm) => {
  if (alarm.name === 'checkNotifications') {
    checkNotificationsBackground();
  }
});

// הקשבה ללחיצה על התראה
chrome.notifications.onClicked.addListener((notificationId) => {
  if (notificationId === 'newNotifications') {
    chrome.runtime.sendMessage({ action: 'openPopup' });
    chrome.notifications.clear(notificationId);
  }
});

chrome.runtime.onStartup.addListener(startBackgroundCheck);
chrome.runtime.onInstalled.addListener(startBackgroundCheck);