document.addEventListener('DOMContentLoaded', () => {
  document.getElementById('version').textContent = chrome.runtime.getManifest().version; // הצגת גרסת התוסף
  loadSites(); // טעינת רשימת האתרים
  loadCheckInterval(); // טעינת תדירות הבדיקה
  loadSoundSettings(); // טעינת הגדרות הצליל

  document.getElementById('decreaseInterval').addEventListener('click', () => updateInterval(-1)); // הפחתת תדירות הבדיקה
  document.getElementById('increaseInterval').addEventListener('click', () => updateInterval(1)); // הגדלת תדירות הבדיקה
  document.getElementById('addSite').addEventListener('click', addSite); // הוספת אתר חדש
  document.getElementById('save').addEventListener('click', saveSites); // שמירת ההגדרות
});

// פונקציה שטוענת את רשימת האתרים מהאחסון
function loadSites() {
  chrome.storage.sync.get('sites', (data) => {
    const sites = data.sites || getDefaultSites();
    const container = document.getElementById('sitesContainer');
    container.innerHTML = `
      <table class="site-table">
        <thead>
          <tr style="font-size:16px">
            <th>סטטוס</th>
            <th>שם האתר</th>
            <th>דף הבית</th>
            <th>פעולות</th>
          </tr>
        </thead>
        <tbody id="siteTableBody"></tbody>
      </table>
    `;
    const tableBody = document.getElementById('siteTableBody');
    sites.forEach((site, index) => {
      const row = document.createElement('tr');
      row.innerHTML = `
        <td>
          <label class="switch">
            <input type="checkbox" id="site${index}" ${site.enabled ? 'checked' : ''}>
            <span class="slider"></span>
          </label>
        </td>
        <td style="font-size:20px">${site.name}</td>
        <td style="font-size:16px">
          <a href="${site.url}" target="_blank" style="color: blue; text-decoration: none;">${site.url.replace(/^https?:\/\//, '')}</a>
        </td>
        <td>
          <button class="remove" data-index="${index}" style="background: none; border: none; padding: 0;">
            <img src="icons/trash-red.png" alt="הסר" style="width: 20px; height: 20px;" />
          </button>
        </td>
      `;
      tableBody.appendChild(row);

      row.querySelector(`#site${index}`).addEventListener('change', () => updateSiteStatus(index, row.querySelector(`#site${index}`).checked));
    });
    document.querySelectorAll('.remove').forEach(button => button.addEventListener('click', removeSite));
  });
}

// פונקציה שמחזירה את רשימת האתרים ברירת המחדל
function getDefaultSites() {
  return [
    { url: 'https://tchumim.com', name: 'תחומים', enabled: true },
    { url: 'https://mitmachim.top', name: 'מתמחים', enabled: true },
    { url: 'https://f2.freeivr.co.il', name: 'פורום ימות המשיח', enabled: true },
    { url: 'https://forum-office.co.il', name: 'פורום אופיס', enabled: true },
    { url: 'https://forum.netfree.link', name: 'פורום נטפרי', enabled: true },
    { url: 'https://forum.safera.co.il', name: 'פורום סייפר', enabled: true },
    { url: 'https://rechavimzelaze.ovh', name: 'רכבים זה לזה', enabled: true },
    { url: 'https://miktzav.com', name: 'מקצב', enabled: true },
    { url: 'https://hamusicay.com', name: 'המוזיקאי', enabled: true }
  ];
}

// פונקציה שמעדכנת את מצב האתר (מופעל/מושבת)
function updateSiteStatus(index, enabled) {
  chrome.storage.sync.get('sites', (data) => {
    const sites = data.sites || getDefaultSites();
    if (sites[index]) {
      sites[index].enabled = enabled;
      chrome.storage.sync.set({ sites });
    }
  });
}

// פונקציה שמוסיפה אתר חדש
function addSite() {
  const name = document.getElementById('newSiteName').value;
  const url = document.getElementById('newSiteUrl').value;
  if (name && url) {
    chrome.storage.sync.get('sites', (data) => {
      const sites = data.sites || getDefaultSites();
      sites.push({ name, url, enabled: true });
      chrome.storage.sync.set({ sites }, loadSites);
    });
    document.getElementById('newSiteName').value = '';
    document.getElementById('newSiteUrl').value = '';
  }
}

// פונקציה שמסירה אתר
function removeSite(event) {
  const index = event.currentTarget.dataset.index;
  chrome.storage.sync.get('sites', (data) => {
    const sites = data.sites || getDefaultSites();
    sites.splice(index, 1);
    chrome.storage.sync.set({ sites }, loadSites);
  });
}

// פונקציה ששומרת את ההגדרות
function saveSites() {
  chrome.storage.sync.get(['sites', 'checkIntervalMinutes', 'playSound'], (data) => {
    const sites = data.sites || getDefaultSites();
    const interval = document.getElementById('checkInterval').value;
    const playSound = document.getElementById('playSound').checked;

    sites.forEach((site, index) => {
      site.enabled = document.getElementById(`site${index}`).checked;
    });

    chrome.storage.sync.set({
      sites: sites,
      checkIntervalMinutes: parseInt(interval),
      playSound: playSound
    }, () => {
      alert('ההגדרות נשמרו בהצלחה!');
    });
  });
}

// פונקציה שטוענת את תדירות הבדיקה
function loadCheckInterval() {
  chrome.storage.sync.get('checkIntervalMinutes', (data) => {
    const interval = data.checkIntervalMinutes || 5;
    document.getElementById('checkInterval').value = interval;
  });
}

// פונקציה שמעדכנת את תדירות הבדיקה
function updateInterval(change) {
  const input = document.getElementById('checkInterval');
  let value = parseInt(input.value) + change;
  value = Math.min(Math.max(value, 1), 60);
  input.value = value;
  saveCheckInterval(value);
}

// פונקציה ששומרת את תדירות הבדיקה
function saveCheckInterval(interval) {
  chrome.storage.sync.set({ checkIntervalMinutes: interval }, () => {
    chrome.runtime.sendMessage({ action: 'updateCheckInterval', interval: interval });
  });
}

// פונקציה שטוענת את הגדרות הצליל
function loadSoundSettings() {
  chrome.storage.sync.get('playSound', (data) => {
    const playSound = data.playSound !== false; // ברירת מחדל: מופעל
    document.getElementById('playSound').checked = playSound;
  });
}